<template>
  <div class="app-container">
    <el-card class="box-card">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
          <el-form-item label="产品SN号" prop="sfcCode">
            <el-input
              v-model="queryParams.sfcCode"
              placeholder="请输入产品SN号"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item label="托盘号" prop="palletNo">
            <el-input
              v-model="queryParams.palletNo"
              placeholder="请输入托盘号"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item label="曲轴码" prop="crankshaftNo">
            <el-input
              v-model="queryParams.crankshaftNo"
              placeholder="请输入曲轴码"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item label="状态" prop="state">
            <el-input
              v-model="queryParams.state"
              placeholder="请输入状态"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item label="连杆码" prop="connectingrodNo">
            <el-input
              v-model="queryParams.connectingrodNo"
              placeholder="请输入连杆码"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item style="float: right">
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>
    </el-card>

    <el-card style="margin-top: 10px" class="box-card">
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button
              type="primary"
              plain
              icon="el-icon-plus"
              size="mini"
              @click="handleAdd"
              v-hasPermi="['da:tileMatchMiddleware:add']"
            >新增</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
              type="success"
              plain
              icon="el-icon-edit"
              size="mini"
              :disabled="single"
              @click="handleUpdate"
              v-hasPermi="['da:tileMatchMiddleware:edit']"
            >修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
              type="danger"
              plain
              icon="el-icon-delete"
              size="mini"
              :disabled="multiple"
              @click="handleDelete"
              v-hasPermi="['da:tileMatchMiddleware:remove']"
            >删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
              type="warning"
              plain
              icon="el-icon-download"
              size="mini"
              @click="handleExport"
              v-hasPermi="['da:tileMatchMiddleware:export']"
            >导出</el-button>
          </el-col>
          <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table border v-loading="loading" :data="tileMatchMiddlewareList" @selection-change="handleSelectionChange">
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column label="ID" align="center" prop="id" />
          <el-table-column label="产品SN号" align="center" prop="sfcCode">
          </el-table-column>
          <el-table-column label="托盘号" align="center" prop="palletNo">
          </el-table-column>
          <el-table-column label="曲轴码" align="center" prop="crankshaftNo">
          </el-table-column>
          <el-table-column label="状态" align="center" prop="state">
          </el-table-column>
          <el-table-column label="备注" align="center" prop="remarks">
          </el-table-column>
          <el-table-column label="连杆码" align="center" prop="connectingrodNo">
          </el-table-column>
          <el-table-column label="气缸编号" align="center" prop="cylinder">
          </el-table-column>
          <el-table-column fixed="right" width="200" label="操作" align="center" class-name="small-padding fixed-width">
            <template slot-scope="scope">
              <el-button
                size="mini"
                type="success"
                plain
                style="width: 72px"
                icon="el-icon-edit"
                @click="handleUpdate(scope.row)"
                v-hasPermi="['da:tileMatchMiddleware:edit']"
              >修改</el-button>
              <el-button
                size="mini"
                type="danger"
                plain
                style="width: 72px"
                icon="el-icon-delete"
                @click="handleDelete(scope.row)"
                v-hasPermi="['da:tileMatchMiddleware:remove']"
              >删除</el-button>
            </template>
          </el-table-column>
        </el-table>
    </el-card>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改活塞连杆配瓦中间对话框 -->
    <el-dialog v-dialogpop-up :title="title" :visible.sync="open" width="500px" append-to-body>
      <span slot="title">
        <i class="el-icon-s-order"></i>
        {{titleName}}
      </span>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="产品SN号" prop="sfcCode">
          <el-input v-model="form.sfcCode" placeholder="请输入产品SN号" />
        </el-form-item>
        <el-form-item label="托盘号" prop="palletNo">
          <el-input v-model="form.palletNo" placeholder="请输入托盘号" />
        </el-form-item>
        <el-form-item label="曲轴码" prop="crankshaftNo">
          <el-input v-model="form.crankshaftNo" placeholder="请输入曲轴码" />
        </el-form-item>
        <el-form-item label="状态" prop="state">
          <el-input v-model="form.state" placeholder="请输入状态" />
        </el-form-item>
        <el-form-item label="备注" prop="remarks">
          <el-input v-model="form.remarks" placeholder="请输入备注" />
        </el-form-item>
        <el-form-item label="连杆码" prop="connectingrodNo">
          <el-input v-model="form.connectingrodNo" placeholder="请输入连杆码" />
        </el-form-item>
        <el-form-item label="气缸编号" prop="cylinder">
          <el-input v-model="form.cylinder" placeholder="请输入气缸编号" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listTileMatchMiddleware, getTileMatchMiddleware, delTileMatchMiddleware, addTileMatchMiddleware, updateTileMatchMiddleware } from "@/api/main/da/tileMatchMiddleware/tileMatchMiddleware";

export default {
  name: "TileMatchMiddleware",
  data() {
    return {
      // 遮罩层
      loading: true,
      titleName: "",
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 活塞连杆配瓦中间表格数据
      tileMatchMiddlewareList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        sfcCode: null,
        palletNo: null,
        crankshaftNo: null,
        state: null,
        remarks: null,
        connectingrodNo: null,
        cylinder: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        id: [
          { required: true, message: "ID不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询活塞连杆配瓦中间列表 */
    getList() {
      this.loading = true;
      listTileMatchMiddleware(this.queryParams).then(response => {
        this.tileMatchMiddlewareList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        sfcCode: null,
        palletNo: null,
        crankshaftNo: null,
        state: null,
        remarks: null,
        connectingrodNo: null,
        cylinder: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.titleName = "添加活塞连杆配瓦中间";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getTileMatchMiddleware(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.titleName = "修改活塞连杆配瓦中间";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateTileMatchMiddleware(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTileMatchMiddleware(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除活塞连杆配瓦中间编号为"' + ids + '"的数据项？').then(function() {
        return delTileMatchMiddleware(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('da/tileMatchMiddleware/export', {
        ...this.queryParams
      }, `tileMatchMiddleware_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
